"""Markdown configuration file management.

Provides Markdown documentation files: README.md (project name header + badges)
and MkDocs pages (docs/index.md, docs/api.md).

Modules:
    readme: README.md configuration management
    docs: MkDocs documentation files (index.md, api.md)

See Also:
    pyrig.dev.configs.base.badges_md.BadgesMarkdownConfigFile
    pyrig.dev.configs.docs.mkdocs.MkdocsConfigFile
"""
