"""Test configuration file management.

Manages pytest test infrastructure: conftest.py (pytest config), fixtures/__init__.py
(custom fixtures), test_main.py (CLI tests), test_zero.py (sanity tests).

See Also:
    pyrig.dev.tests.conftest
    pytest documentation: https://docs.pytest.org/
"""
