"""Git-related configuration file management.

Provides .gitignore (GitHub Python patterns + pyrig-specific) and
.pre-commit-config.yaml (local hooks for ruff, ty, bandit, rumdl) to maintain
code quality and prevent committing unwanted files.

Modules:
    gitignore: .gitignore file configuration management
    pre_commit: .pre-commit-config.yaml file configuration management

See Also:
    GitHub gitignore templates: https://github.com/github/gitignore
    pre-commit framework: https://pre-commit.com/
"""
